## ----set.up, include=FALSE, messages=FALSE, warnings=FALSE--------------------
knitr::opts_chunk$set(message=FALSE, collapse = TRUE, comment="")
library(SummarizedExperiment)
library(devtools)
load_all()

## ----load.data----------------------------------------------------------------

# Load pre-simulated feature set 
# See ?sim_FS for more information
data(sim_FS)

# Load pre-computed input-score
# See ?sim_Scores for more information
data(sim_Scores)


## ----ks.method----------------------------------------------------------------

candidate_search_res <- CaDrA::candidate_search(
  FS = sim_FS,
  input_score = sim_Scores,
  method = "ks_pval",          # Use Kolmogorow-Smirnow scoring function 
  alternative = "less",        # Use one-sided hypothesis testing
  weights = NULL,              # If weights is provided, perform a weighted-KS test
  search_method = "both",      # Apply both forward and backward search
  top_N = 7,                   # Number of top features to kick start the search
  max_size = 10,               # Allow at most 10 features in meta-feature matrix
  best_score_only = FALSE      # Return meta-feature, its observed input scores and corresponding best score
)


## ----ks.meta.plot-------------------------------------------------------------

# Extract the best meta-feature result
topn_best_meta <- CaDrA::topn_best(topn_list = candidate_search_res)

# Visualize meta-feature result
CaDrA::meta_plot(topn_best_list = topn_best_meta)


## ----ks.perm.res, include=FALSE-----------------------------------------------

# Load pre-computed permutation-based testings
# See ?perm_res for more information
data("perm_res")


## ----ks.permutation.plot------------------------------------------------------

# Visualize permutation results
permutation_plot(perm_res = perm_res)


## ----RsessionInfo-------------------------------------------------------------
sessionInfo()

